/**
 * CMI : Cluster Method Invocation
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: carol@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * --------------------------------------------------------------------------
 * $Id: CMIInvocationContext.java 1823 2008-06-03 18:03:18Z loris $
 * --------------------------------------------------------------------------
 */

package org.ow2.cmi.rpc;

import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.Map;

import javax.interceptor.InvocationContext;

import org.ow2.cmi.reference.CMIReferenceable;

/**
 * @author Loris Bouzonnet
 */
public class CMIInvocationContext<T> implements InvocationContext {

    private final CMIReferenceable<T> cmiReferenceable;

    private final CMIInvocationInfo info;

    private final Method method;

    private Object[] parameters;

    public CMIInvocationContext(
            final CMIReferenceable<T> cmiReferenceable,
            final CMIInvocationInfo info,
            final Method method) {
        this.cmiReferenceable = cmiReferenceable;
        this.info = info;
        this.method = method;
    }

    public Map<String, Object> getContextData() {
        return new HashMap<String, Object>();
    }

    public Method getMethod() {
        return method;
    }

    public Object[] getParameters() {
        return parameters;
    }

    public T getTarget() {
        return cmiReferenceable.getReferencedObject();
    }

    public Object proceed() throws Exception {
        return method.invoke(cmiReferenceable.getReferencedObject(), parameters);
    }

    public void setParameters(final Object[] paremeters) {
        this.parameters = paremeters;
    }

}
